
.. include:: ../README.rst

.. include::   authors.rst

=================
Table of Contents
=================

.. toctree::
   :maxdepth: 1

   usage
   API <phasespace>
   contributing
   authors
   history
